globals 
[  
  global-new-author-publication-rate 
  global-academics-start-age-min
  global-academics-start-age-max
  global-academics-retire-age 
  
  careerist-publication-by-tick
  orthodox-publication-by-tick
  producer-publication-by-tick
  careerist-impact-by-tick
  orthodox-impact-by-tick
  producer-impact-by-tick
]
breed [ journals journal ]
breed [ academics academic ]

journals-own [ journal-type impact-factor acceptance-rate topically-fitting-factor monthly-published-paper academics-with-publication ]
academics-own [ academic-type start-age start-tick total-publication total-impact journals-with-publication current-journal-id ]

to clear
  clear-all
end

to setup
  clear-all
  global-values  
  create-agents
  reset-ticks
end

to go
  if ticks > global-total-ticks [ stop ]
  clear-links
  academics-move-around
  academics-submit-papers
  journals-publish-papers
  academics-retire
  tick
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;; setup ;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to global-values
  
  set global-new-author-publication-rate 0.41
  
  set global-academics-start-age-min 30.0
  set global-academics-start-age-max 30.9
  set global-academics-retire-age 65.0
end

to create-agents
  create-agent-journals
  create-agent-academics
end

; create three types of journals
to create-agent-journals
  
  create-journals num-journal-if  [
    set journal-type "IF"
    set impact-factor random-float-between-inclusive ( if-journal-if-min ) ( if-journal-if-max )
    set topically-fitting-factor random-float-between-inclusive ( if-journal-tff-min ) ( if-journal-tff-max )
    set acceptance-rate random-float-between-inclusive ( if-journal-ar-min ) ( if-journal-ar-max )
    set monthly-published-paper random-integer-between-inclusive ( if-journal-monthly-paper-min ) ( if-journal-monthly-paper-max )
    set color red
  ]
  
  create-journals num-journal-tff  [
    set journal-type "TFF"
    set impact-factor random-float-between-inclusive ( tff-journal-if-min ) ( tff-journal-if-max )
    set topically-fitting-factor random-float-between-inclusive ( tff-journal-tff-min ) ( tff-journal-tff-max )
    set acceptance-rate random-float-between-inclusive ( tff-journal-ar-min ) ( tff-journal-ar-max )
    set monthly-published-paper random-integer-between-inclusive ( tff-journal-monthly-paper-min ) ( tff-journal-monthly-paper-max )
    set color green
  ]
  
  create-journals num-journal-ar  [
    set journal-type "AR"
    set impact-factor random-float-between-inclusive ( ar-journal-if-min ) ( ar-journal-if-max )
    set topically-fitting-factor random-float-between-inclusive ( ar-journal-tff-min ) ( ar-journal-tff-max )
    set acceptance-rate random-float-between-inclusive ( ar-journal-ar-min ) ( ar-journal-ar-max )
    set monthly-published-paper random-integer-between-inclusive ( ar-journal-monthly-paper-min ) ( ar-journal-monthly-paper-max )
    set color yellow
  ]
  
  ask journals [  
    set shape "house" 
    set academics-with-publication []
    fd random 200
  ]
end


; create three types of academics
to create-agent-academics 
  create-academics num-Aca-Careerist [
    set academic-type "careerist"
    set color red
  ]
  
  create-academics num-Aca-Orthodox [
    set academic-type "orthodox"  
    set color green
  ]
  
  create-academics num-Aca-Producer [ 
    set academic-type "mass-producer"  
    set color yellow     
  ]
  
  ask academics [
    set shape "person"     
    set start-age random-float-between-inclusive ( global-academics-start-age-min ) ( global-academics-retire-age )
    set start-tick 0
    set total-publication 0
    set total-impact 0
    set journals-with-publication []
    set current-journal-id -1
    fd random 200
  ]
  
end



to-report random-float-between-inclusive [ a b ]
  report precision ( a + ( random-float (b - a) ) ) 1
end

to-report random-integer-between-inclusive [a b]
  report ( a + ( random (b - a) ) )
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;; iteration ;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; academics move around randomly
to academics-move-around
  ask academics [ 
    set current-journal-id -1
    
    fd random global-academic-move-limit 
    rt random global-academic-move-limit 
    lt random global-academic-move-limit ]
  
  set careerist-publication-by-tick 0
  set orthodox-publication-by-tick 0
  set producer-publication-by-tick 0
  set careerist-impact-by-tick 0
  set orthodox-impact-by-tick 0
  set producer-impact-by-tick 0
  
end

; academic submit papers to their preferred journals
to academics-submit-papers
  ask academics [
    let academic-id who
    
    let journals-if journals in-radius global-academic-journal-in-radius with [ journal-type = "IF" ]
    let journals-tff journals in-radius global-academic-journal-in-radius with [ journal-type = "TFF" ]
    let journals-ar journals in-radius global-academic-journal-in-radius with [ journal-type = "AR" ]
    
    if academic-type = "careerist" and count journals-if > 0 [ submit-paper-to-if-journals (who) (journals-if) ]
    if academic-type = "orthodox" and count journals-tff > 0 [ submit-paper-to-tff-journals (who) (journals-tff) ]
    if academic-type = "mass-producer" and count journals-ar > 0 [ submit-paper-to-ar-journals (who) (journals-ar) ]
  ]
end

; submit paper from careerist to IF journals
to submit-paper-to-if-journals [ academic-id target-journals ]
    
  let journal-to-submit one-of target-journals
  
  if count target-journals > 1
  [
    let max-if-journals target-journals with [ impact-factor = max [impact-factor] of target-journals ]
    
    ifelse count max-if-journals = 1 
    [
      set journal-to-submit one-of max-if-journals
    ]
    [
      let max-ar-journals max-if-journals with [ acceptance-rate = max [acceptance-rate] of max-if-journals ]
      
      ifelse count max-ar-journals = 1
      [
        set journal-to-submit one-of max-ar-journals
      ]
      [
        let max-tff-journals max-ar-journals with [ topically-fitting-factor = max [ topically-fitting-factor ] of max-ar-journals ]
        
        set journal-to-submit one-of  max-tff-journals
      ]
    ]
  ]

  submit-paper ( academic-id ) ( journal-to-submit )
end

; submit paper from orthodox to TFF journals
to submit-paper-to-tff-journals [ academic-id target-journals ]
    
  let journal-to-submit one-of target-journals
  if count target-journals > 1
  [
    let max-tff-journals target-journals with [ topically-fitting-factor = max [topically-fitting-factor] of target-journals ]
    
    ifelse count max-tff-journals = 1 
    [
      set journal-to-submit one-of max-tff-journals
    ]
    [
      let max-ar-journals max-tff-journals with [ acceptance-rate = max [acceptance-rate] of max-tff-journals ]
      
      ifelse count max-ar-journals = 1
      [
        set journal-to-submit one-of max-ar-journals  
      ]
      [
        let max-if-journals max-ar-journals with [ impact-factor = max [ impact-factor ] of max-ar-journals ]
        
        set journal-to-submit one-of max-if-journals
      ]
    ]
  ]
  
  submit-paper ( academic-id ) ( journal-to-submit )
end

; submit paper from mass producer to AR journals
to submit-paper-to-ar-journals [ academic-id target-journals ]
    
  let journal-to-submit one-of target-journals
  if count target-journals > 1
  [
    let max-ar-journals target-journals with [ acceptance-rate = max [acceptance-rate] of target-journals ]
    
    ifelse count max-ar-journals = 1 
    [
      set journal-to-submit one-of max-ar-journals
    ]
    [
      let max-if-journals max-ar-journals with [ impact-factor = max [impact-factor] of max-ar-journals ]
      
      ifelse count max-if-journals = 1
      [
        set journal-to-submit one-of max-if-journals
      ]
      [
        let max-tff-journals max-if-journals with [ topically-fitting-factor = max [ topically-fitting-factor ] of max-if-journals ]
        
        set journal-to-submit one-of max-tff-journals
      ]
    ]
  ]
  
  submit-paper ( academic-id ) ( journal-to-submit )
end

; submit paper from specific academic to specific journal
to submit-paper [ academic-id journal-to-submit ]
  ask journals with [ who = [ who ] of journal-to-submit ] 
  [
    create-link-from academic academic-id
  ]

  ask academics with [ who = academic-id ]
  [
    set current-journal-id [ who ] of journal-to-submit
  ]
end


; journal publish papers from submissions
; based on the acceptance rate and Lotka's law
to journals-publish-papers
  clear-links
  ask journals [
    ; calculate total submission and how many papers are to accept
    let journal-id who
    let total-submission-received  count academics with [ current-journal-id = journal-id ]
    let acceptable-paper-count floor( acceptance-rate * total-submission-received )
    if acceptable-paper-count > monthly-published-paper [ set acceptable-paper-count monthly-published-paper ]
    
    ; Lotka's law
    ; new authors pool based on the simon's rate defined in global settings
    ; and seasoned authors pool
    let new-author-pool floor ( acceptable-paper-count * global-new-author-publication-rate )
    let seasoned-author-pool acceptable-paper-count - new-author-pool
    
    let new-author-count 0
    let seasoned-author-count 0
    
    ; review process and then publish paper
    ask academics in-radius global-academic-journal-in-radius [
      if current-journal-id = journal-id
      [
        ifelse length journals-with-publication = 0
        [
          if new-author-count < new-author-pool [
            
            set new-author-count new-author-count + 1
            publish-paper (journal-id) (who) 
          ]
        ] 
        [
          if seasoned-author-count < seasoned-author-pool [
            
            set seasoned-author-count seasoned-author-count + 1 
            publish-paper (journal-id) (who)
          ]
        ]
      ]
    ]
  ]
end

; publish paper from specific academic to specific journal
to publish-paper [ journal-id academic-id ]
  let this-if 0
  
  ; update journal and academic details
  ask journals with [ who = journal-id ] [
    create-link-to academic academic-id
    set academics-with-publication fput academic-id academics-with-publication
    set this-if impact-factor
  ]

  ; update academic details
  ask academics with [ who = academic-id ] [
    
    set total-publication total-publication + 1
    set total-impact total-impact + this-if
    set journals-with-publication fput journal-id journals-with-publication
    
    if academic-type = "careerist"
    [   
      set careerist-publication-by-tick careerist-publication-by-tick + 1
      set careerist-impact-by-tick careerist-impact-by-tick + this-if
    ]
    
    if academic-type = "orthodox"
    [
      set orthodox-publication-by-tick orthodox-publication-by-tick + 1
      set orthodox-impact-by-tick orthodox-impact-by-tick + this-if
    ]
    
    if academic-type = "mass-producer"
    [
      set producer-publication-by-tick producer-publication-by-tick + 1
      set producer-impact-by-tick producer-impact-by-tick + this-if
    ]
  ]
end


; retire academics & recruit new
to academics-retire
  
  ask academics with [ start-age + precision ( ( ticks - start-tick ) / 12 ) 2 >= global-academics-retire-age ]
  [ 
    hatch 1 [
      set start-age random-float-between-inclusive ( global-academics-start-age-min ) ( global-academics-start-age-max )
      set start-tick ticks
      set total-publication 0
      set total-impact 0
      set journals-with-publication []
      set current-journal-id -1
    ]
    
    die
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;; plot ;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Academic Publication ;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to draw-total-careerist
  let total-count 0
  ask academics with [ academic-type = "careerist" ] [ 
    set total-count total-count + total-publication ]
  let total-aca count academics with [ academic-type = "careerist" ]
  if total-aca > 0 [ plot total-count / total-aca ]
end

to draw-total-orthodox
  let total-count 0
  ask academics with [ academic-type = "orthodox" ] [ 
    set total-count total-count + total-publication ]
  let total-aca count academics with [ academic-type = "orthodox" ]
  if total-aca > 0 [ plot total-count / total-aca ]
end

to draw-total-producer
  let total-count 0
  ask academics with [ academic-type = "mass-producer" ] [
    set total-count total-count + total-publication ]
  let total-aca count academics with [ academic-type = "mass-producer" ]
  if total-aca > 0 [ plot total-count / total-aca ] 
end


to draw-total-academics  
  let count-careerist-publication 0
  ask academics with [ academic-type = "careerist" ] [ 
    set count-careerist-publication count-careerist-publication + total-publication ]
  let count-careerist count academics with [ academic-type = "careerist" ]
  let careerist-publication 0
  if count-careerist > 0 [ set careerist-publication count-careerist-publication / count-careerist ]
  
  let count-orthodox-publication 0
  ask academics with [ academic-type = "orthodox" ] [ 
    set count-orthodox-publication count-orthodox-publication + total-publication ]
  let count-orthodox count academics with [ academic-type = "orthodox" ]
  let orthodox-publication 0
  if count-orthodox > 0 [ set orthodox-publication count-orthodox-publication / count-orthodox ]
  
  let count-producer-publication 0
  ask academics with [ academic-type = "mass-producer" ] [ 
    set count-producer-publication count-producer-publication + total-publication ]
  let count-producer count academics with [ academic-type = "mass-producer" ]
  let producer-publication 0
  if count-producer > 0 [ set producer-publication count-producer-publication / count-producer ]
      
  plot ( careerist-publication + orthodox-publication + producer-publication ) / 3 
end 



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;; Academic Impact ;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to draw-careerist-if  
  let count-total-impact 0
  ask academics with [ academic-type = "careerist" ] [ 
    set count-total-impact count-total-impact + total-impact ]
  let total-aca count academics with [ academic-type = "careerist" ]
  if total-aca > 0 [ plot count-total-impact / total-aca ]
end 

to draw-orthodox-if  
  let count-total-impact 0
  ask academics with [ academic-type = "orthodox" ] [ 
    set count-total-impact count-total-impact + total-impact ]
  let total-aca count academics with [ academic-type = "orthodox" ]
  if total-aca > 0 [ plot count-total-impact / total-aca ]
end 

to draw-producer-if  
  let count-total-impact 0
  ask academics with [ academic-type = "mass-producer" ] [ 
    set count-total-impact count-total-impact + total-impact ]
  let total-aca count academics with [ academic-type = "mass-producer" ]
  if total-aca > 0 [ plot count-total-impact / total-aca ]
end 

to draw-academics-if  
  let count-careerist-impact 0
  ask academics with [ academic-type = "careerist" ] [ 
    set count-careerist-impact count-careerist-impact + total-impact ]
  let count-careerist count academics with [ academic-type = "careerist" ]
  let careerist-if 0
  if count-careerist > 0 [ set careerist-if count-careerist-impact / count-careerist ]
  
  let count-orthodox-impact 0
  ask academics with [ academic-type = "orthodox" ] [ 
    set count-orthodox-impact count-orthodox-impact + total-impact ]
  let count-orthodox count academics with [ academic-type = "orthodox" ]
  let orthodox-if 0
  if count-orthodox > 0 [ set orthodox-if count-orthodox-impact / count-orthodox ]
  
  let count-producer-impact 0
  ask academics with [ academic-type = "mass-producer" ] [ 
    set count-producer-impact count-producer-impact + total-impact ]
  let count-producer count academics with [ academic-type = "mass-producer" ]
  let producer-if 0
  if count-producer > 0 [ set producer-if count-producer-impact / count-producer ]
      
  plot ( careerist-if + orthodox-if + producer-if ) / 3 
end 



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;; Time Tick ;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to draw-careerist-productivity-by-tick
    plot careerist-publication-by-tick / count academics with [ academic-type = "careerist" ]
end

to draw-orthodox-productivity-by-tick
    plot  orthodox-publication-by-tick / count academics with [ academic-type = "orthodox" ]
end

to draw-producer-productivity-by-tick
    plot  producer-publication-by-tick / count academics with [ academic-type = "mass-producer" ] 
end

to draw-average-productivity-by-tick
  plot ( careerist-publication-by-tick / count academics with [ academic-type = "careerist" ] + 
    orthodox-publication-by-tick / count academics with [ academic-type = "orthodox" ] + 
    producer-publication-by-tick / count academics with [ academic-type = "mass-producer" ] ) / 3
end

to draw-careerist-impact-by-tick
  plot careerist-impact-by-tick / count academics with [ academic-type = "careerist" ]
end

to draw-orthodox-impact-by-tick
  plot orthodox-impact-by-tick / count academics with [ academic-type = "orthodox" ]
end

to draw-producer-impact-by-tick
  plot producer-impact-by-tick / count academics with [ academic-type = "mass-producer" ]
end

to draw-average-impact-by-tick
  plot (  careerist-impact-by-tick / count academics with [ academic-type = "careerist" ] +
     orthodox-impact-by-tick / count academics with [ academic-type = "orthodox" ] +
     producer-impact-by-tick / count academics with [ academic-type = "mass-producer" ] ) / 3
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;; Age ;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to Plot3035IF
  let count-total-impact 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 < 35 ) ] [
    set count-total-impact count-total-impact + total-impact
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 < 35 ) ]
  if ( total-aca > 0 ) [
    plot count-total-impact / total-aca
  ]
end

to Plot3540IF
  let count-total-impact 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 35 ) and ( start-age + ( ticks - start-tick ) / 12 < 40 ) ] [
    set count-total-impact count-total-impact + total-impact
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 35 ) and ( start-age + ( ticks - start-tick ) / 12 < 40 ) ]
  if ( total-aca > 0 ) [
    plot count-total-impact / total-aca
  ]
end
to Plot4045IF
  let count-total-impact 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 40 ) and ( start-age + ( ticks - start-tick ) / 12 < 45 ) ] [
    set count-total-impact count-total-impact + total-impact
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 40 ) and ( start-age + ( ticks - start-tick ) / 12 < 45 ) ]
  if ( total-aca > 0 ) [
    plot count-total-impact / total-aca
  ]
end
to Plot4550IF
    let count-total-impact 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 45 ) and ( start-age + ( ticks - start-tick ) / 12 < 50 ) ] [
    set count-total-impact count-total-impact + total-impact
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 45 ) and ( start-age + ( ticks - start-tick ) / 12 < 50 ) ]
  if ( total-aca > 0 ) [
    plot count-total-impact / total-aca
  ]
end
to Plot5055IF
    let count-total-impact 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 50 ) and ( start-age + ( ticks - start-tick ) / 12 < 55 ) ] [
    set count-total-impact count-total-impact + total-impact
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 50 ) and ( start-age + ( ticks - start-tick ) / 12 < 55 ) ]
  if ( total-aca > 0 ) [
    plot count-total-impact / total-aca
  ]
end
to Plot5560IF
    let count-total-impact 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 55 ) and ( start-age + ( ticks - start-tick ) / 12 < 60 ) ] [
    set count-total-impact count-total-impact + total-impact
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 55 ) and ( start-age + ( ticks - start-tick ) / 12 < 60 ) ]
  if ( total-aca > 0 ) [
    plot count-total-impact / total-aca
  ]
end
to Plot6065IF
    let count-total-impact 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 60 ) and ( start-age + ( ticks - start-tick ) / 12 < 65 ) ] [
    set count-total-impact count-total-impact + total-impact
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 60 ) and ( start-age + ( ticks - start-tick ) / 12 < 65 ) ]
  if ( total-aca > 0 ) [
    plot count-total-impact / total-aca
  ]
end

;============================================================================

to PlotPaper3035
  let count-total-publication 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 < 35 ) ] [
    set count-total-publication total-publication + count-total-publication
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 < 35 ) ]
  if ( total-aca > 0 ) [
    plot count-total-publication / total-aca
  ]
end
to PlotPaper3540
  let count-total-publication 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 35 ) and ( start-age + ( ticks - start-tick ) / 12 < 40 ) ] [
    set count-total-publication total-publication + count-total-publication
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 35 ) and ( start-age + ( ticks - start-tick ) / 12 < 40 ) ]
  if ( total-aca > 0 ) [
    plot count-total-publication / total-aca
  ]
end
to PlotPaper4045
  let count-total-publication 0
  ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 40 ) and ( start-age + ( ticks - start-tick ) / 12 < 45 ) ] [
    set count-total-publication total-publication + count-total-publication
  ]
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 40 ) and ( start-age + ( ticks - start-tick ) / 12 < 45 ) ]
  if ( total-aca > 0 ) [
    plot count-total-publication / total-aca
  ]
end
to PlotPaper4550
  let count-total-publication 0
    ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 45 ) and ( start-age + ( ticks - start-tick ) / 12 < 50 ) ] [
    set count-total-publication total-publication + count-total-publication
  ]  
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 45 ) and ( start-age + ( ticks - start-tick ) / 12 < 50 ) ]
  if ( total-aca > 0 ) [
    plot count-total-publication / total-aca
  ]
end
to PlotPaper5055
  let count-total-publication 0
    ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 50 ) and ( start-age + ( ticks - start-tick ) / 12 < 55 ) ] [
    set count-total-publication total-publication + count-total-publication
  ]  
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 50 ) and ( start-age + ( ticks - start-tick ) / 12 < 55 ) ]
  if ( total-aca > 0 ) [
    plot count-total-publication / total-aca
  ]
end
to PlotPaper5560
  let count-total-publication 0
    ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 55 ) and ( start-age + ( ticks - start-tick ) / 12 < 60 ) ] [
    set count-total-publication total-publication + count-total-publication
  ]  
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 55 ) and ( start-age + ( ticks - start-tick ) / 12 < 60 ) ]
  if ( total-aca > 0 ) [
    plot count-total-publication / total-aca
  ]
end
to PlotPaper6065
  let count-total-publication 0
    ask academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 60 ) and ( start-age + ( ticks - start-tick ) / 12 < 65 ) ] [
    set count-total-publication total-publication + count-total-publication
  ]  
  let total-aca count academics with [ ( start-age + ( ticks - start-tick ) / 12 >= 60 ) and ( start-age + ( ticks - start-tick ) / 12 < 65 ) ]
  if ( total-aca > 0 ) [
    plot count-total-publication / total-aca
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
556
10
1195
432
26
16
11.87
1
10
1
1
1
0
1
1
1
-26
26
-16
16
0
0
1
ticks
30.0

BUTTON
76
10
142
43
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
7
10
71
43
Clear
clear
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
11
319
149
352
num-aca-producer
num-aca-producer
0
500
200
1
1
NIL
HORIZONTAL

BUTTON
150
10
213
43
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
11
245
148
278
num-aca-careerist
num-aca-careerist
0
500
200
1
1
NIL
HORIZONTAL

SLIDER
11
282
148
315
num-aca-orthodox
num-aca-orthodox
0
500
200
1
1
NIL
HORIZONTAL

PLOT
1202
10
1461
215
Productivity by Academic Type
time tick
paper count
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"Careerist" 1.0 0 -2674135 true "" "draw-total-careerist"
"Orthodox" 1.0 0 -13840069 true "" "draw-total-orthodox"
"Producer" 1.0 0 -1184463 true "" "draw-total-producer"
"Average" 1.0 0 -7500403 true "" "draw-total-academics"

PLOT
1203
216
1462
430
Impact by Academic Type
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"Careerist" 1.0 0 -2674135 true "" "draw-careerist-if"
"Orthodox" 1.0 0 -10899396 true "" "draw-orthodox-if"
"Producer" 1.0 0 -1184463 true "" "draw-producer-if"
"Average" 1.0 0 -7500403 true "" "draw-academics-if"

PLOT
557
436
880
668
Productivity by Age Group
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"30-35" 1.0 0 -16777216 true "" "PlotPaper3035"
"35-40" 1.0 0 -7500403 true "" "PlotPaper3540"
"40-45" 1.0 0 -2674135 true "" "PlotPaper4045"
"45-50" 1.0 0 -955883 true "" "PlotPaper4550"
"50-55" 1.0 0 -6459832 true "" "PlotPaper5055"
"55-60" 1.0 0 -1184463 true "" "PlotPaper5560"
"60-65" 1.0 0 -10899396 true "" "PlotPaper6065"

PLOT
1465
10
1736
215
Average Productivity by Academic Type by Tick
NIL
NIL
0.0
10.0
0.0
0.1
true
false
"" ""
PENS
"Careerist" 0.1 0 -2674135 true "" "draw-careerist-productivity-by-tick"
"Orthodox" 0.1 0 -10899396 true "" "draw-orthodox-productivity-by-tick"
"Producer" 0.1 0 -1184463 true "" "draw-producer-productivity-by-tick"
"Average" 0.1 0 -7500403 true "" "draw-average-productivity-by-tick"

PLOT
1465
217
1737
430
Average Impact by Academic Type by Tick
NIL
NIL
0.0
10.0
0.0
0.01
true
false
"" ""
PENS
"Careerist" 1.0 0 -2674135 true "" "draw-careerist-impact-by-tick"
"Orthodox" 1.0 0 -10899396 true "" "draw-orthodox-impact-by-tick"
"Producer" 1.0 0 -1184463 true "" "draw-producer-impact-by-tick"
"Average" 1.0 0 -7500403 true "" "draw-average-impact-by-tick"

PLOT
885
436
1194
668
Impact by Age Group
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"30-35" 1.0 0 -16777216 true "" "Plot3035IF"
"35-40" 1.0 0 -7500403 true "" "Plot3540IF"
"40-45" 1.0 0 -2674135 true "" "Plot4045IF"
"45-50" 1.0 0 -955883 true "" "Plot4550IF"
"50-55" 1.0 0 -6459832 true "" "Plot5055IF"
"55-60" 1.0 0 -1184463 true "" "Plot5560IF"
"60-65" 1.0 0 -10899396 true "" "Plot6065IF"

SLIDER
9
136
213
169
global-academic-move-limit
global-academic-move-limit
0
50
20
1
1
NIL
HORIZONTAL

SLIDER
11
376
152
409
num-journal-if
num-journal-if
0
20
20
1
1
NIL
HORIZONTAL

SLIDER
11
412
153
445
num-journal-tff
num-journal-tff
0
20
20
1
1
NIL
HORIZONTAL

SLIDER
11
448
154
481
num-journal-ar
num-journal-ar
0
20
20
1
1
NIL
HORIZONTAL

SLIDER
8
174
213
207
global-academic-journal-in-radius
global-academic-journal-in-radius
0
20
10
1
1
NIL
HORIZONTAL

SLIDER
9
100
213
133
global-total-ticks
global-total-ticks
0
1000
420
1
1
NIL
HORIZONTAL

TEXTBOX
12
56
212
112
1 tick = 1 month. 420 ticks = 35 years.   It is a complete life cycle for an academic from 30 to 65.
11
0.0
1

TEXTBOX
252
11
402
29
Settings for IF Journal
11
0.0
1

SLIDER
250
27
378
60
if-journal-if-min
if-journal-if-min
0
1
0.8
0.1
1
NIL
HORIZONTAL

SLIDER
383
27
510
60
if-journal-if-max
if-journal-if-max
0
1
0.9
0.1
1
NIL
HORIZONTAL

TEXTBOX
13
226
163
244
Number of academics
11
0.0
1

TEXTBOX
13
359
163
377
Number of journals
11
0.0
1

SLIDER
249
63
377
96
if-journal-tff-min
if-journal-tff-min
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
383
62
511
95
if-journal-tff-max
if-journal-tff-max
0
1
0.6
0.1
1
NIL
HORIZONTAL

SLIDER
249
98
378
131
if-journal-ar-min
if-journal-ar-min
0
1
0.2
0.1
1
NIL
HORIZONTAL

SLIDER
382
98
512
131
if-journal-ar-max
if-journal-ar-max
0
1
0.3
0.1
1
NIL
HORIZONTAL

SLIDER
248
133
449
166
if-journal-monthly-paper-min
if-journal-monthly-paper-min
0
20
3
1
1
NIL
HORIZONTAL

SLIDER
247
169
449
202
if-journal-monthly-paper-max
if-journal-monthly-paper-max
0
30
10
1
1
NIL
HORIZONTAL

TEXTBOX
248
213
398
231
Settings for TFF Journal
11
0.0
1

SLIDER
246
229
377
262
tff-journal-if-min
tff-journal-if-min
0
1
0.3
0.1
1
NIL
HORIZONTAL

SLIDER
381
228
517
261
tff-journal-if-max
tff-journal-if-max
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
246
264
377
297
tff-journal-tff-min
tff-journal-tff-min
0
1
0.7
0.1
1
NIL
HORIZONTAL

SLIDER
381
263
517
296
tff-journal-tff-max
tff-journal-tff-max
0
1
0.9
0.1
1
NIL
HORIZONTAL

SLIDER
245
299
377
332
tff-journal-ar-min
tff-journal-ar-min
0
1
0.3
0.1
1
NIL
HORIZONTAL

SLIDER
381
299
518
332
tff-journal-ar-max
tff-journal-ar-max
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
245
334
447
367
tff-journal-monthly-paper-min
tff-journal-monthly-paper-min
0
30
8
1
1
NIL
HORIZONTAL

SLIDER
245
370
447
403
tff-journal-monthly-paper-max
tff-journal-monthly-paper-max
0
30
15
1
1
NIL
HORIZONTAL

TEXTBOX
247
410
397
428
Settings for AR Journal
11
0.0
1

SLIDER
245
425
374
458
ar-journal-if-min
ar-journal-if-min
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
378
424
508
457
ar-journal-if-max
ar-journal-if-max
0
1
0.2
0.1
1
NIL
HORIZONTAL

SLIDER
245
460
374
493
ar-journal-tff-min
ar-journal-tff-min
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
378
460
508
493
ar-journal-tff-max
ar-journal-tff-max
0
1
0.6
0.1
1
NIL
HORIZONTAL

SLIDER
245
496
375
529
ar-journal-ar-min
ar-journal-ar-min
0
1
0.7
0.1
1
NIL
HORIZONTAL

SLIDER
378
496
507
529
ar-journal-ar-max
ar-journal-ar-max
0
1
0.8
0.1
1
NIL
HORIZONTAL

SLIDER
244
532
447
565
ar-journal-monthly-paper-min
ar-journal-monthly-paper-min
0
30
12
1
1
NIL
HORIZONTAL

SLIDER
244
567
447
600
ar-journal-monthly-paper-max
ar-journal-monthly-paper-max
0
30
20
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This model is to simulate the publication activities of academics

## HOW IT WORKS

Academic submit papers. Journal review papers. Journal publish papers.

## HOW TO USE IT

Clear button => Setup button => Go button
Global variable: number of careerist academics, number of orthodox academics, 
number of mass producer academics, and number of journals

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

Gilbert, N. (1997). "A Simulation of the Structure of Academic Science." Sociological Research Online 2(2).

Mölders, M., et al. (2011). "Modeling Scientists as Agents. How Scientists Cope with the Challenges of the New Public Management of Science." Journal of Artificial Societies and Social Simulation 14(4): 6.


## CREDITS AND REFERENCES

Gilbert, N. (1997). "A Simulation of the Structure of Academic Science." Sociological Research Online 2(2).

Lotka, A. J. (1926). "The frequency distribution of scientific productivity." Journal of Washington Academy Sciences 16: 317-323.

Mölders, M., et al. (2011). "Modeling Scientists as Agents. How Scientists Cope with the Challenges of the New Public Management of Science." Journal of Artificial Societies and Social Simulation 14(4): 6.

Simon, H. A. (1957). On a Class of Skew Distribution Functions. Models of Man; Social and Rational. New York, John Wiley & Sons, Inc.

	
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
